'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Transaction = require('cashlib/lib/Transaction');

var _Transaction2 = _interopRequireDefault(_Transaction);

var _Input = require('cashlib/lib/Input');

var _Input2 = _interopRequireDefault(_Input);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _MenuOption = require('tooey/lib/MenuOption');

var _MenuOption2 = _interopRequireDefault(_MenuOption);

var _TransactionInput = require('./TransactionInput');

var _TransactionInput2 = _interopRequireDefault(_TransactionInput);

var _TransactionAddInput = require('./TransactionAddInput');

var _TransactionAddInput2 = _interopRequireDefault(_TransactionAddInput);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TransactionInputs extends _ViewBase2.default {

  constructor() {
    super('Transaction Inputs');

    // Build menu
    const menuOptions = [new _MenuOption2.default('S', 'Show', 'Show details for selected input', this.toDetails.bind(this)), new _MenuOption2.default('A', 'Add', 'Add new input', async () => _app2.default.pushView(new _TransactionAddInput2.default()))];
    this._menu = new _Menu2.default(_app2.default, menuOptions);

    const transaction = _state2.default.transactions.active;
    const columns = [{
      heading: 'Transaction Id',
      width: 64,
      value: input => input.isCoinbase ? 'Coinbase' : input.transactionId
    }, {
      heading: 'Output',
      width: 8,
      value: input => input.isCoinbase ? ' ' : input.outputIndex.toString()
    }, {
      heading: 'Sig?',
      width: 4,
      value: input => input.signatureScript.length ? 'Yes' : ''
    }];

    this._list = new _List2.default(_app2.default, columns, transaction.inputs, {
      rowSelection: true,
      menu: this._menu
    });
  }

  async toDetails() {
    const input = _state2.default.transactions.active.inputs[this._list.selectedRowIndex];
    if (input) {
      _app2.default.pushView(new _TransactionInput2.default(input, _state2.default.transactions.active.getId(), this._list.selectedRowIndex));
    } else {
      _app2.default.setWarning('No input selected');
    }
  }

  render() {
    // Render outputs list
    this._list.render();

    // Render menu last for correct cursor positioning
    this._menu.render(false);
  }

  async handle(key) {
    await this._menu.handle(key);
    await this._list.handle(key);
  }
}
exports.default = TransactionInputs;